==> openjdk-src-11.0.1.u13-2-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_eu.java <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_eu extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ESP", "\u20a7" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Arabiar Emirerri Batuetako dirhama" },
            { "afn", "Afganistango afghania" },
            { "all", "Albaniako leka" },
            { "amd", "Armeniako drama" },
            { "ang", "Holandarren Antilletako guilderra" },
            { "aoa", "Angolako kwanza" },
            { "ars", "Argentinako pesoa" },
            { "aud", "Australiako dolarra" },
            { "awg", "Arubako florina" },
            { "azn", "Azerbaijango manata" },
            { "bam", "Bosnia-Herzegovinako marko trukakorra" },
            { "bbd", "Barbadosetako dolarra" },
            { "bdt", "Bangladesheko taka" },
            { "bgn", "Bulgariako leva" },
            { "bhd", "Bahraingo dinarra" },
            { "bif", "Burundiko frankoa" },
            { "bmd", "Bermudetako dolarra" },
            { "bnd", "Bruneiko dolarra" },
            { "bob", "Boliviako bolivianoa" },
            { "brl", "Brasilgo erreala" },
            { "bsd", "Bahametako dolarra" },
            { "btn", "Bhutango ngultruma" },
            { "bwp", "Bosniako pula" },
            { "byn", "Bielorrusiako errubloa" },
            { "byr", "Bielorrusiako errubloa (2000\u20132016)" },
            { "bzd", "Belizeko dolarra" },
            { "cad", "Kanadako dolarra" },
            { "cdf", "Kongoko frankoa" },
            { "chf", "Suitzako frankoa" },
            { "clp", "Txileko pesoa" },
            { "cnh", "yuan txinatar (itsasoz haraindikoa)" },
            { "cny", "Txinako yuana" },
            { "cop", "Kolonbiako pesoa" },
            { "crc", "Costa Ricako colona" },
            { "cuc", "Kubako peso trukakorra" },
            { "cup", "Kubako pesoa" },
            { "cve", "Cabo Verdeko ezkutua" },
            { "czk", "Txekiar Errepublikako koroa" },
            { "djf", "Djibutiko frankoa" },
            { "dkk", "Danimarkako koroa" },
            { "dop", "Dominikar Errepublikako pesoa" },
            { "dzd", "Aljeriako dinarra" },
            { "egp", "Egiptoko libera" },
            { "ern", "Eritreako nakfa" },
            { "etb", "Etiopiako birra" },
            { "eur", "euroa" },
            { "fjd", "Fijiko dolarra" },
            { "fkp", "Falkland uharteetako libera" },
            { "gbp", "Libera esterlina" },
            { "gel", "Georgiako laria" },
            { "ghs", "Ghanako cedia" },
            { "gip", "Gibraltarreko libera" },
            { "gmd", "Ganbiako dalasia" },
            { "gnf", "Gineako frankoa" },
            { "gtq", "Guatemalako quetzala" },
            { "gyd", "Guyanako dolarra" },
            { "hkd", "Hong Kongeko dolarra" },
            { "hnl", "Hondurasko lempira" },
            { "hrk", "Kroaziako kuna" },
            { "htg", "Haitiko gourdea" },
            { "huf", "Hungariako florina" },
            { "idr", "Indonesiako errupia" },
            { "ils", "Israelgo shekel berria" },
            { "inr", "Indiako errupia" },
            { "iqd", "Irakeko dinarra" },
            { "irr", "Irango riala" },
            { "isk", "Islandiako koroa" },
            { "jmd", "Jamaikako dolarra" },
            { "jod", "Jordaniako dinarra" },
            { "jpy", "Japoniako yena" },
            { "kes", "Kenyako txelina" },
            { "kgs", "Kirgizistango soma" },
            { "khr", "Kanbodiako riela" },
            { "kmf", "Komoreetako frankoa" },
            { "kpw", "Ipar Koreako wona" },
            { "krw", "Hego Koreako wona" },
            { "kwd", "Kuwaiteko dinarra" },
            { "kyd", "Kaiman uharteetako dolarra" },
            { "kzt", "Kazakhstango tengea" },
            { "lak", "Laoseko kipa" },
            { "lbp", "Libanoko libera" },
            { "lkr", "Sri Lankako errupia" },
            { "lrd", "Liberiako dolarra" },
            { "lsl", "Lesothoko lotia" },
            { "ltl", "Lituaniako litasa" },
            { "lvl", "Letoniako latsa" },
            { "lyd", "Libiako dinarra" },
            { "mad", "Marokoko dirhama" },
            { "mdl", "Moldaviako leua" },
            { "mga", "Madagaskarreko ariarya" },
            { "mkd", "Mazedoniako dinarra" },
            { "mmk", "Myanmarreko kyata" },
            { "mnt", "Mongoliako tugrika" },
            { "mop", "Macanako pataca" },
            { "mro", "Mauritaniako ouguiya (1973\u20132017)" },
            { "mru", "Mauritaniako ouguiya" },
            { "mur", "Maurizio uharteetako errupia" },
            { "mvr", "Maldivetako rufiyaa" },
            { "mwk", "Malawiko kwacha" },
            { "mxn", "Mexikoko pesoa" },
            { "myr", "Malaysiako ringgita" },
            { "mzn", "Mozambikeko metikala" },
            { "nad", "Namibiako dolarra" },
            { "ngn", "Nigeriako naira" },
            { "nio", "Nikaraguako cordoba" },
            { "nok", "Norvegiako koroa" },
            { "npr", "Nepalgo errupia" },
            { "nzd", "Zeelanda Berriko dolarra" },
            { "omr", "Omango riala" },
            { "pab", "Panamako balboa" },
            { "pen", "Peruko sol" },
            { "pgk", "Papua Ginea Berriko kina" },
            { "php", "Filipinetako pesoa" },
            { "pkr", "Pakistango errupia" },
            { "pln", "Poloniako zlotya" },
            { "pyg", "Paraguaiko guarania" },
            { "qar", "Qatarreko riala" },
            { "ron", "Errumaniako leua" },
            { "rsd", "Serbiako dinarra" },
            { "rub", "Errusiako errubloa" },
            { "rwf", "Ruandako frankoa" },
            { "sar", "Arabia Saudiko riala" },
            { "sbd", "Salomon uharteetako dolarra" },
            { "scr", "Seychelleetako errupia" },
            { "sdg", "Sudango libera" },
            { "sek", "Suediako koroa" },
            { "sgd", "Singapurreko dolarra" },
            { "shp", "Santa Helenako libera" },
            { "sll", "Sierra Leonako leona" },
            { "sos", "Somaliako txelina" },
            { "srd", "Surinameko dolarra" },
            { "ssp", "Hego Sudango libera" },
            { "std", "Sao Tomeko eta Principeko dobra (1977\u20132017)" },
            { "stn", "Sao Tomeko eta Principeko dobra" },
            { "syp", "Siriako libera" },
            { "szl", "Swazilandiako lilangenia" },
            { "thb", "Thailandiako bahta" },
            { "tjs", "Tajikistango somonia" },
            { "tmt", "Turkmenistango manata" },
            { "tnd", "Tunisiako dinarra" },
            { "top", "Tongako Pa\u02bbanga" },
            { "try", "Turkiako lira" },
            { "ttd", "Trinidad eta Tobagoko dolarra" },
            { "twd", "Taiwango dolar berria" },
            { "tzs", "Tanzaniako txelina" },
            { "uah", "Ukrainako hryvnia" },
            { "ugx", "Ugandako txelina" },
            { "usd", "AEBko dolarra" },
            { "uyu", "Uruguaiko pesoa" },
            { "uzs", "Uzbekistango soma" },
            { "vef", "Venezuelako bolivarra" },
            { "vnd", "Vietnameko donga" },
            { "vuv", "Vanuatuko vatua" },
            { "wst", "Samoko tala" },
            { "xaf", "Afrika erdialdeko CFA frankoa" },
            { "xcd", "Karibe ekialdeko dolarra" },
            { "xof", "Afrika mendebaldeko CFA frankoa" },
            { "xpf", "CFP frankoa" },
            { "xxx", "Moneta ezezaguna" },
            { "yer", "Yemengo riala" },
            { "zar", "Hegoafrikako randa" },
            { "zmk", "Zambiako kwacha (1968\u20132012)" },
            { "zmw", "Zambiako kwacha" },
        };
        return data;
    }
}

==> openjdk-src-13.0.1.u9-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_eu.java <==
/*
 * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_eu extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ESP", "\u20a7" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Arabiar Emirerri Batuetako dirhama" },
            { "afn", "Afganistango afghania" },
            { "all", "Albaniako leka" },
            { "amd", "Armeniako drama" },
            { "ang", "Holandarren Antilletako guilderra" },
            { "aoa", "Angolako kwanza" },
            { "ars", "Argentinako pesoa" },
            { "aud", "Australiako dolarra" },
            { "awg", "Arubako florina" },
            { "azn", "Azerbaijango manata" },
            { "bam", "Bosnia-Herzegovinako marko trukakorra" },
            { "bbd", "Barbadosetako dolarra" },
            { "bdt", "Bangladesheko taka" },
            { "bgn", "Bulgariako leva" },
            { "bhd", "Bahraingo dinarra" },
            { "bif", "Burundiko frankoa" },
            { "bmd", "Bermudetako dolarra" },
            { "bnd", "Bruneiko dolarra" },
            { "bob", "Boliviako bolivianoa" },
            { "brl", "Brasilgo erreala" },
            { "bsd", "Bahametako dolarra" },
            { "btn", "Bhutango ngultruma" },
            { "bwp", "Bosniako pula" },
            { "byn", "Bielorrusiako errubloa" },
            { "byr", "Bielorrusiako errubloa (2000\u20132016)" },
            { "bzd", "Belizeko dolarra" },
            { "cad", "Kanadako dolarra" },
            { "cdf", "Kongoko frankoa" },
            { "chf", "Suitzako frankoa" },
            { "clp", "Txileko pesoa" },
            { "cnh", "yuan txinatar (itsasoz haraindikoa)" },
            { "cny", "Txinako yuana" },
            { "cop", "Kolonbiako pesoa" },
            { "crc", "Costa Ricako colona" },
            { "cuc", "Kubako peso trukakorra" },
            { "cup", "Kubako pesoa" },
            { "cve", "Cabo Verdeko ezkutua" },
            { "czk", "Txekiar Errepublikako koroa" },
            { "djf", "Djibutiko frankoa" },
            { "dkk", "Danimarkako koroa" },
            { "dop", "Dominikar Errepublikako pesoa" },
            { "dzd", "Aljeriako dinarra" },
            { "egp", "Egiptoko libera" },
            { "ern", "Eritreako nakfa" },
            { "etb", "Etiopiako birra" },
            { "eur", "euroa" },
            { "fjd", "Fijiko dolarra" },
            { "fkp", "Falkland uharteetako libera" },
            { "gbp", "Libera esterlina" },
            { "gel", "Georgiako laria" },
            { "ghs", "Ghanako cedia" },
            { "gip", "Gibraltarreko libera" },
            { "gmd", "Ganbiako dalasia" },
            { "gnf", "Gineako frankoa" },
            { "gtq", "Guatemalako quetzala" },
            { "gyd", "Guyanako dolarra" },
            { "hkd", "Hong Kongeko dolarra" },
            { "hnl", "Hondurasko lempira" },
            { "hrk", "Kroaziako kuna" },
            { "htg", "Haitiko gourdea" },
            { "huf", "Hungariako florina" },
            { "idr", "Indonesiako errupia" },
            { "ils", "Israelgo shekel berria" },
            { "inr", "Indiako errupia" },
            { "iqd", "Irakeko dinarra" },
            { "irr", "Irango riala" },
            { "isk", "Islandiako koroa" },
            { "jmd", "Jamaikako dolarra" },
            { "jod", "Jordaniako dinarra" },
            { "jpy", "Japoniako yena" },
            { "kes", "Kenyako txelina" },
            { "kgs", "Kirgizistango soma" },
            { "khr", "Kanbodiako riela" },
            { "kmf", "Komoreetako frankoa" },
            { "kpw", "Ipar Koreako wona" },
            { "krw", "Hego Koreako wona" },
            { "kwd", "Kuwaiteko dinarra" },
            { "kyd", "Kaiman uharteetako dolarra" },
            { "kzt", "Kazakhstango tengea" },
            { "lak", "Laoseko kipa" },
            { "lbp", "Libanoko libera" },
            { "lkr", "Sri Lankako errupia" },
            { "lrd", "Liberiako dolarra" },
            { "lsl", "Lesothoko lotia" },
            { "ltl", "Lituaniako litasa" },
            { "lvl", "Letoniako latsa" },
            { "lyd", "Libiako dinarra" },
            { "mad", "Marokoko dirhama" },
            { "mdl", "Moldaviako leua" },
            { "mga", "Madagaskarreko ariarya" },
            { "mkd", "Mazedoniako dinarra" },
            { "mmk", "Myanmarreko kyata" },
            { "mnt", "Mongoliako tugrika" },
            { "mop", "Macanako pataca" },
            { "mro", "Mauritaniako ouguiya (1973\u20132017)" },
            { "mru", "Mauritaniako ouguiya" },
            { "mur", "Maurizio uharteetako errupia" },
            { "mvr", "Maldivetako rufiyaa" },
            { "mwk", "Malawiko kwacha" },
            { "mxn", "Mexikoko pesoa" },
            { "myr", "Malaysiako ringgita" },
            { "mzn", "Mozambikeko metikala" },
            { "nad", "Namibiako dolarra" },
            { "ngn", "Nigeriako naira" },
            { "nio", "Nikaraguako cordoba" },
            { "nok", "Norvegiako koroa" },
            { "npr", "Nepalgo errupia" },
            { "nzd", "Zeelanda Berriko dolarra" },
            { "omr", "Omango riala" },
            { "pab", "Panamako balboa" },
            { "pen", "Peruko sol" },
            { "pgk", "Papua Ginea Berriko kina" },
            { "php", "Filipinetako pesoa" },
            { "pkr", "Pakistango errupia" },
            { "pln", "Poloniako zlotya" },
            { "pyg", "Paraguaiko guarania" },
            { "qar", "Qatarreko riala" },
            { "ron", "Errumaniako leua" },
            { "rsd", "Serbiako dinarra" },
            { "rub", "Errusiako errubloa" },
            { "rwf", "Ruandako frankoa" },
            { "sar", "Arabia Saudiko riala" },
            { "sbd", "Salomon uharteetako dolarra" },
            { "scr", "Seychelleetako errupia" },
            { "sdg", "Sudango libera" },
            { "sek", "Suediako koroa" },
            { "sgd", "Singapurreko dolarra" },
            { "shp", "Santa Helenako libera" },
            { "sll", "Sierra Leonako leona" },
            { "sos", "Somaliako txelina" },
            { "srd", "Surinameko dolarra" },
            { "ssp", "Hego Sudango libera" },
            { "std", "Sao Tomeko eta Principeko dobra (1977\u20132017)" },
            { "stn", "Sao Tome eta Principeko dobra" },
            { "syp", "Siriako libera" },
            { "szl", "Swazilandiako lilangenia" },
            { "thb", "Thailandiako bahta" },
            { "tjs", "Tajikistango somonia" },
            { "tmt", "Turkmenistango manata" },
            { "tnd", "Tunisiako dinarra" },
            { "top", "Tongako Pa\u02bbanga" },
            { "try", "Turkiako lira" },
            { "ttd", "Trinidad eta Tobagoko dolarra" },
            { "twd", "Taiwango dolar berria" },
            { "tzs", "Tanzaniako txelina" },
            { "uah", "Ukrainako hryvnia" },
            { "ugx", "Ugandako txelina" },
            { "usd", "AEBko dolarra" },
            { "uyu", "Uruguaiko pesoa" },
            { "uzs", "Uzbekistango soma" },
            { "vef", "Venezuelako bolivarra (2008\u20132018)" },
            { "ves", "Venezuelako bolivarra" },
            { "vnd", "Vietnameko donga" },
            { "vuv", "Vanuatuko vatua" },
            { "wst", "Samoko tala" },
            { "xaf", "Afrika erdialdeko CFA frankoa" },
            { "xcd", "Karibe ekialdeko dolarra" },
            { "xof", "Afrika mendebaldeko CFA frankoa" },
            { "xpf", "CFP frankoa" },
            { "xxx", "Moneta ezezaguna" },
            { "yer", "Yemengo riala" },
            { "zar", "Hegoafrikako randa" },
            { "zmk", "Zambiako kwacha (1968\u20132012)" },
            { "zmw", "Zambiako kwacha" },
        };
        return data;
    }
}
